@@ -18,21 +18,23 @@ class TestDataset(BaseTestCase):
         cloud_storage_client = GoogleCloudStorageClient()
 
         cloud_storage_client.upload_from_string(
-            "[1, 2, 3]", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_0.txt"
+            "[1, 2, 3]", cloud_path=storage.path.generate_gs_path(TEST_BUCKET_NAME, dataset_name, "file_0.txt")
         )
 
         cloud_storage_client.upload_from_string(
-            "[4, 5, 6]", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_1.txt"
+            "[4, 5, 6]", cloud_path=storage.path.generate_gs_path(TEST_BUCKET_NAME, dataset_name, "file_1.txt")
         )
 
         cloud_storage_client.upload_from_string(
-            "['a', 'b', 'c']", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/sub-directory/sub_file.txt"
+            "['a', 'b', 'c']",
+            cloud_path=storage.path.generate_gs_path(TEST_BUCKET_NAME, dataset_name, "sub-directory/sub_file.txt"),
         )
 
         cloud_storage_client.upload_from_string(
             "['blah', 'b', 'c']",
-            bucket_name=TEST_BUCKET_NAME,
-            path_in_bucket=f"{dataset_name}/sub-directory/sub-sub-directory/sub_sub_file.txt",
+            cloud_path=storage.path.generate_gs_path(
+                TEST_BUCKET_NAME, dataset_name, "sub-directory", "sub-sub-directory", "sub_sub_file.txt"
+            ),
         )
 
     def _create_files_and_nested_subdirectories(self, directory_path):
@@ -282,35 +284,20 @@ class TestDataset(BaseTestCase):
             dataset = create_dataset_with_two_files(temporary_directory)
             dataset.tags = {"a": "b", "c": 1}
 
-            dataset.to_cloud(bucket_name=TEST_BUCKET_NAME, output_directory="a_directory")
+            cloud_path = storage.path.generate_gs_path(TEST_BUCKET_NAME, "a_directory", dataset.name)
+            dataset.to_cloud(cloud_path)
+            persisted_dataset = Dataset.from_cloud(cloud_path)
 
-            path_to_dataset_directory = storage.path.join("a_directory", dataset.name)
-            gs_path = f"gs://{TEST_BUCKET_NAME}/{path_to_dataset_directory}"
+            self.assertEqual(persisted_dataset.path, f"gs://{TEST_BUCKET_NAME}/a_directory/{dataset.name}")
+            self.assertEqual(persisted_dataset.id, dataset.id)
+            self.assertEqual(persisted_dataset.name, dataset.name)
+            self.assertEqual(persisted_dataset.hash_value, dataset.hash_value)
+            self.assertEqual(persisted_dataset.tags, dataset.tags)
+            self.assertEqual(persisted_dataset.labels, dataset.labels)
+            self.assertEqual({file.name for file in persisted_dataset.files}, {file.name for file in dataset.files})
 
-            for location_parameters in (
-                {
-                    "bucket_name": TEST_BUCKET_NAME,
-                    "path_to_dataset_directory": path_to_dataset_directory,
-                    "cloud_path": None,
-                },
-                {"bucket_name": None, "path_to_dataset_directory": None, "cloud_path": gs_path},
-            ):
-
-                with self.subTest(**location_parameters):
-                    persisted_dataset = Dataset.from_cloud(**location_parameters)
-
-                    self.assertEqual(persisted_dataset.path, f"gs://{TEST_BUCKET_NAME}/a_directory/{dataset.name}")
-                    self.assertEqual(persisted_dataset.id, dataset.id)
-                    self.assertEqual(persisted_dataset.name, dataset.name)
-                    self.assertEqual(persisted_dataset.hash_value, dataset.hash_value)
-                    self.assertEqual(persisted_dataset.tags, dataset.tags)
-                    self.assertEqual(persisted_dataset.labels, dataset.labels)
-                    self.assertEqual(
-                        {file.name for file in persisted_dataset.files}, {file.name for file in dataset.files}
-                    )
-
-                    for file in persisted_dataset:
-                        self.assertEqual(file.path, f"gs://{TEST_BUCKET_NAME}/a_directory/{dataset.name}/{file.name}")
+            for file in persisted_dataset:
+                self.assertEqual(file.path, f"gs://{TEST_BUCKET_NAME}/a_directory/{dataset.name}/{file.name}")
 
     def test_from_cloud_with_no_datafile_metadata_file(self):
         """Test that any cloud directory can be accessed as a dataset if it has no `dataset_metadata.json` metadata
@@ -398,56 +385,39 @@ class TestDataset(BaseTestCase):
         )
 
     def test_to_cloud(self):
-        """Test that a dataset can be uploaded to the cloud via (`bucket_name`, `output_directory`) and via
-        `cloud_path`, including all its files and a serialised JSON file of the Datafile instance.
+        """Test that a dataset can be uploaded to the cloud, including all its files and a serialised JSON file of the
+        Datafile instance.
         """
         with tempfile.TemporaryDirectory() as temporary_directory:
-            dataset_directory_name = os.path.split(temporary_directory)[-1]
             dataset = create_dataset_with_two_files(temporary_directory)
             dataset.tags = {"a": "b", "c": 1}
 
             output_directory = "my_datasets"
-            cloud_path = storage.path.generate_gs_path(TEST_BUCKET_NAME, output_directory)
+            cloud_path = storage.path.generate_gs_path(TEST_BUCKET_NAME, output_directory, dataset.name)
 
-            for location_parameters in (
-                {"bucket_name": TEST_BUCKET_NAME, "output_directory": output_directory, "cloud_path": None},
-                {"bucket_name": None, "output_directory": None, "cloud_path": cloud_path},
-            ):
-                with self.subTest(**location_parameters):
-                    dataset.to_cloud(**location_parameters)
+            dataset.to_cloud(cloud_path)
 
-                    storage_client = GoogleCloudStorageClient()
+            storage_client = GoogleCloudStorageClient()
 
-                    persisted_file_0 = storage_client.download_as_string(
-                        cloud_path=storage.path.join(cloud_path, dataset.name, "file_0.txt"),
-                    )
+            persisted_file_0 = storage_client.download_as_string(cloud_path=storage.path.join(cloud_path, "file_0.txt"))
+            self.assertEqual(persisted_file_0, "0")
 
-                    self.assertEqual(persisted_file_0, "0")
+            persisted_file_1 = storage_client.download_as_string(storage.path.join(cloud_path, "file_1.txt"))
+            self.assertEqual(persisted_file_1, "1")
 
-                    persisted_file_1 = storage_client.download_as_string(
-                        bucket_name=TEST_BUCKET_NAME,
-                        path_in_bucket=storage.path.join(output_directory, dataset.name, "file_1.txt"),
-                    )
-                    self.assertEqual(persisted_file_1, "1")
+            persisted_dataset = json.loads(
+                storage_client.download_as_string(storage.path.join(cloud_path, definitions.DATASET_METADATA_FILENAME))
+            )
 
-                    persisted_dataset = json.loads(
-                        storage_client.download_as_string(
-                            bucket_name=TEST_BUCKET_NAME,
-                            path_in_bucket=storage.path.join(
-                                output_directory, dataset.name, definitions.DATASET_METADATA_FILENAME
-                            ),
-                        )
-                    )
+            self.assertEqual(
+                persisted_dataset["files"],
+                [
+                    f"gs://octue-test-bucket/my_datasets/{dataset.name}/file_0.txt",
+                    f"gs://octue-test-bucket/my_datasets/{dataset.name}/file_1.txt",
+                ],
+            )
 
-                    self.assertEqual(
-                        persisted_dataset["files"],
-                        [
-                            f"gs://octue-test-bucket/my_datasets/{dataset_directory_name}/file_0.txt",
-                            f"gs://octue-test-bucket/my_datasets/{dataset_directory_name}/file_1.txt",
-                        ],
-                    )
-
-                    self.assertEqual(persisted_dataset["tags"], dataset.tags.to_primitive())
+            self.assertEqual(persisted_dataset["tags"], dataset.tags.to_primitive())
 
     def test_to_cloud_with_nested_dataset_preserves_nested_structure(self):
         """Test that uploading a dataset containing datafiles in a nested directory structure to the cloud preserves
@@ -480,10 +450,12 @@ class TestDataset(BaseTestCase):
 
         dataset_name = "another-dataset"
         storage_client.upload_from_string(
-            string=json.dumps([1, 2, 3]), bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_0.txt"
+            string=json.dumps([1, 2, 3]),
+            cloud_path=storage.path.generate_gs_path(TEST_BUCKET_NAME, dataset_name, "file_0.txt"),
         )
         storage_client.upload_from_string(
-            string=json.dumps([4, 5, 6]), bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_1.txt"
+            string=json.dumps([4, 5, 6]),
+            cloud_path=storage.path.generate_gs_path(TEST_BUCKET_NAME, dataset_name, "file_1.txt"),
         )
 
         dataset = Dataset.from_cloud(cloud_path=f"gs://{TEST_BUCKET_NAME}/{dataset_name}")
